@@ -20,7 +20,14 @@ const char *plugin_version="LiVES asf/wmv decoder version 1.0";
 #undef HAVE_AV_CONFIG_H
 #endif
 
-#include <libavcodec/avcodec.h>
+#define HAVE_AVCODEC
+
+#ifdef HAVE_SYSTEM_WEED_COMPAT
+#include "weed/weed-compat.h"
+#else
+#include "../../../libweed/weed-compat.h"
+#endif
+
 #include <libavformat/avformat.h>
 #include <libavutil/avstring.h>
 
@@ -49,53 +56,6 @@ static enum CodecID ff_codec_get_id(const AVCodecTag *tags, unsigned int tag)
 
 ////////////////////////////////////////////////////////////////////////////
 
-static int pix_fmt_to_palette(enum PixelFormat pix_fmt, int *clamped) {
- 
-  switch (pix_fmt) {
-  case PIX_FMT_RGB24:
-    return WEED_PALETTE_RGB24;
-  case PIX_FMT_BGR24:
-    return WEED_PALETTE_BGR24;
-  case PIX_FMT_RGBA:
-    return WEED_PALETTE_RGBA32;
-  case PIX_FMT_BGRA:
-    return WEED_PALETTE_BGRA32;
-  case PIX_FMT_ARGB:
-    return WEED_PALETTE_ARGB32;
-  case PIX_FMT_YUV444P:
-    return WEED_PALETTE_YUV444P;
-  case PIX_FMT_YUV422P:
-    return WEED_PALETTE_YUV422P;
-  case PIX_FMT_YUV420P:
-    return WEED_PALETTE_YUV420P;
-  case PIX_FMT_YUYV422:
-    return WEED_PALETTE_YUYV;
-  case PIX_FMT_UYVY422:
-    return WEED_PALETTE_UYVY;
-  case PIX_FMT_UYYVYY411:
-    return WEED_PALETTE_YUV411;
-  case PIX_FMT_GRAY8:
-  case PIX_FMT_Y400A:
-    return WEED_PALETTE_A8;
-  case PIX_FMT_MONOWHITE:
-  case PIX_FMT_MONOBLACK:
-    return WEED_PALETTE_A1;
-  case PIX_FMT_YUVJ422P:
-    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-    return WEED_PALETTE_YUV422P;
-  case PIX_FMT_YUVJ444P:
-    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-    return WEED_PALETTE_YUV444P;
-  case PIX_FMT_YUVJ420P:
-    if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-    return WEED_PALETTE_YUV420P;
-
-  default:
-    return WEED_PALETTE_END;
-  }
-}
-
-
 
 /* can enable this later to handle pix_fmt (35) - YUVA4204P */
 /*
@@ -409,7 +369,7 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
   uint32_t packet_length, padsize;
   unsigned char buffer[8];
   uint8_t num;
-  uint16_t duration;
+  //uint16_t duration;
   int rsize;
   int streamid;
   int pack_fill=0;
@@ -501,7 +461,7 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
       }
       priv->input_position+=2;
       
-      duration = get_le16int(buffer);
+      //duration = get_le16int(buffer);
       
       // rsize has at least 11 bytes which have to be present
       
@@ -675,7 +635,7 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
 	printf("got vid fragment in packet !\n");
 #endif
 
-	if (asf->packet_key_frame&&asf->packet_frag_offset==0) {
+	if (asf->packet_key_frame&&asf->packet_frag_offset==0&&priv->have_start_dts) {
 	  priv->kframe=add_keyframe(cdata,priv->hdr_start,priv->fragnum,asf->packet_frag_timestamp-priv->start_dts);
 #ifdef DEBUG
 	  printf("and is keyframe !\n");
@@ -914,7 +874,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->arate=0;
   cdata->achans=0;
   cdata->asamps=0;
-  snprintf(cdata->audio_name,16,"none");
+  sprintf(cdata->audio_name,"none");
 
   priv->idx=NULL;
 
@@ -1031,7 +991,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       }
       
       priv->input_position+=8;
-      priv->asf->hdr.send_time          = get_le64int(buffer);   // seems to be the duration
+      // seems to be the duration
+      priv->asf->hdr.send_time = get_le64int(buffer);
 
 #ifdef DEBUG
       fprintf(stderr,"hdr says send time is %ld\n",priv->asf->hdr.send_time);
@@ -1103,11 +1064,11 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
     } else if (!guidcmp(&g, &lives_asf_stream_header)) {
       enum LiVESMediaType type;
-      int type_specific_size, sizeX;
-      uint64_t total_size;
+      int sizeX;
+      //uint64_t total_size;
       unsigned int tag1;
       int64_t pos1, pos2, start_time;
-      int test_for_ext_stream_audio, is_dvr_ms_audio=0;
+      int test_for_ext_stream_audio;
 
       pos1 = priv->input_position;
 
@@ -1169,7 +1130,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       
       priv->input_position+=8;
 
-      total_size = get_le64int(buffer);
+      //      total_size = get_le64int(buffer);
 
       if (read(priv->fd,buffer,4)<4) {
 	fprintf(stderr, "asf_decoder: read error in %s\n",cdata->URI);
@@ -1179,7 +1140,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       
       priv->input_position+=4;
 
-      type_specific_size = get_le32int(buffer);
+      //type_specific_size = get_le32int(buffer);
       
       lseek(priv->fd, 4, SEEK_CUR);
       priv->input_position+=4;
@@ -1205,7 +1166,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	
 	if (!guidcmp(&g, &lives_asf_ext_stream_audio_stream)) {
 	  type = LIVES_MEDIA_TYPE_AUDIO;
-	  is_dvr_ms_audio=1;
+	  //is_dvr_ms_audio=1;
 	  get_guid(priv->fd, &g);
 	  priv->input_position+=sizeof(lives_asf_guid);
 
@@ -1221,13 +1182,12 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       }
 
 
-
       if (type == LIVES_MEDIA_TYPE_AUDIO) {
 	priv->st->codec->codec_type = AVMEDIA_TYPE_AUDIO;
 	snprintf(cdata->audio_name,16,"unknown");
 
       } else if (type == LIVES_MEDIA_TYPE_VIDEO) {
-	priv->st->codec->codec_type = CODEC_TYPE_VIDEO;
+	priv->st->codec->codec_type = AVMEDIA_TYPE_VIDEO;
 	if (vidindex!=-1&&vidindex!=priv->st->id) {
 	  fprintf(stderr, "asf_decoder: unhandled multiple vidstreams %d and %d in %s\n",vidindex,priv->st->id,cdata->URI);
 	  got_vidst=TRUE;
@@ -1558,7 +1518,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       }
   
     } else if (!guidcmp(&g, &lives_asf_metadata_header)) {
-      int n, stream_num, name_len, value_len, value_type, value_num;
+      int n, stream_num, name_len, value_len, value_num;
 
       if (read(priv->fd,buffer,2)<2) {
 	fprintf(stderr, "asf_decoder: read error in %s\n",cdata->URI);
@@ -1604,7 +1564,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	  
 	priv->input_position+=2;
 	
-	value_type= get_le16int(buffer);
+	//value_type= get_le16int(buffer);
 
 	if (read(priv->fd,buffer,4)<4) {
 	  fprintf(stderr, "asf_decoder: read error in %s\n",cdata->URI);
@@ -1636,8 +1596,11 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	  
 	value_num= get_le16int(buffer);
 
-	//url_fskip(pb, value_len - 2);
-	
+	// check this
+	priv->input_position+=value_len-2;
+	lseek(priv->fd, value_len+2, SEEK_CUR);
+
+
 	if(stream_num<128){
 	  if     (!strcmp(name, "AspectRatioX")) dar[stream_num].num= 
 						   value_num;
@@ -1652,7 +1615,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       }
     } else if (!guidcmp(&g, &lives_asf_ext_stream_header)) {
       int ext_len, payload_ext_ct, stream_ct;
-      uint32_t ext_d, leak_rate, stream_num;
+      uint32_t leak_rate, stream_num;
       unsigned int stream_languageid_index;
 
       lseek(priv->fd, 16, SEEK_CUR); // startime, endtime
@@ -1781,7 +1744,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	      
 	priv->input_position+=2;
 	      
-	ext_d=get_le16int(buffer);
+	//ext_d=get_le16int(buffer);
 	      
 	if (read(priv->fd,buffer,4)<4) {
 	  fprintf(stderr, "asf_decoder: read error in %s\n",cdata->URI);
@@ -1842,7 +1805,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
       priv->input_position+=name_len;
 
       for(i=0;i<count;i++){
-	int64_t pres_time;
+	//	int64_t pres_time;
 	int name_len;
 	
 	lseek(priv->fd, 8, SEEK_CUR);
@@ -1856,7 +1819,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     
 	priv->input_position+=8;
 
-	pres_time = get_le64int(buffer); // presentation time
+	//pres_time = get_le64int(buffer); // presentation time
 	
 	lseek(priv->fd, 10, SEEK_CUR);
 	priv->input_position+=10;
@@ -1957,6 +1920,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->data_start=priv->input_position;
 
+  priv->start_dts=0; // will reset this later
+  priv->have_start_dts=FALSE; // cannot add keyframes until we know offset of start_dts
+
   // re-scan with avcodec; priv->data_start holds video data start position
   priv->input_position=priv->data_start;
   lseek(priv->fd,priv->input_position,SEEK_SET);
@@ -2028,7 +1994,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     return FALSE;
   }
 
-#if LIBAVCODEC_VERSION_MAJOR >= 53
+#if LIBAVCODEC_VERSION_MAJOR >= 52
   len=avcodec_decode_video2(vidst->codec, priv->picture, &got_picture, &priv->avpkt );
 #else 
   len=avcodec_decode_video(vidst->codec, priv->picture, &got_picture, priv->avpkt.data, priv->avpkt.size );
@@ -2048,6 +2014,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   }
 
   pts=priv->start_dts=priv->frame_dts;
+  priv->have_start_dts=TRUE;
 
 #ifdef DEBUG
   printf("first pts is %ld\n",pts);
@@ -2109,7 +2076,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   cdata->palettes=(int *)malloc(2*sizeof(int));
 
-  cdata->palettes[0]=pix_fmt_to_palette(ctx->pix_fmt,&cdata->YUV_clamping);
+  cdata->palettes[0]=avi_pix_fmt_to_weed_palette(ctx->pix_fmt,
+						 &cdata->YUV_clamping);
   cdata->palettes[1]=WEED_PALETTE_END;
 
   if (cdata->palettes[0]==WEED_PALETTE_END) {
