@@ -509,6 +509,7 @@ typedef struct {
   int64_t hdr_start;  ///< file offset of current asf packet
   int64_t start_dts;  ///< first video dts
   int64_t frame_dts;
+  boolean have_start_dts;
   boolean black_fill;
   size_t def_packet_size;
   off_t filesize;
@@ -563,11 +564,11 @@ typedef struct {
 #define DO_2BITS(bits, var, defval)					\
   switch (bits & 3)							\
     {									\
-      int dummy;							\
+      int dummy=0;							\
     case 3: dummy=read(priv->fd,buffer,4); var = get_le32int(buffer); priv->input_position+=4; rsize+=4; break; \
     case 2: dummy=read (priv->fd,buffer,2); var = get_le16int(buffer); priv->input_position+=2; rsize+=2; break; \
     case 1: dummy=read (priv->fd,buffer,1); var = *buffer; priv->input_position++; rsize++; break; \
-    default: var = defval; break;					\
+    default: var = defval; dummy=dummy; break;				\
     }
 
 
