@@ -10,65 +10,32 @@
 #include <stdlib.h>
 #include <math.h>
 
-const char *plugin_version="LiVES flv decoder version 0.1";
+const char *plugin_version="LiVES flv decoder version 1.0";
 
 #ifdef HAVE_AV_CONFIG_H
 #undef HAVE_AV_CONFIG_H
 #endif
 
-#include <libavcodec/avcodec.h>
+#ifdef HAVE_AV_CONFIG_H
+#undef HAVE_AV_CONFIG_H
+#endif
+
+#define HAVE_AVCODEC
+
+#ifdef HAVE_SYSTEM_WEED_COMPAT
+#include "weed/weed-compat.h"
+#else
+#include "../../../libweed/weed-compat.h"
+#endif
+
+#include <libavformat/avformat.h>
+#include <libavutil/avstring.h>
 
 #include "decplugin.h"
 #include "flv_decoder.h"
 
 ////////////////////////////////////////////////////////////////////////////
 
-static int pix_fmt_to_palette(enum PixelFormat pix_fmt, int *clamped) {
- 
-    switch (pix_fmt) {
-    case PIX_FMT_RGB24:
-	return WEED_PALETTE_RGB24;
-    case PIX_FMT_BGR24:
-	return WEED_PALETTE_BGR24;
-    case PIX_FMT_RGBA:
-	return WEED_PALETTE_RGBA32;
-    case PIX_FMT_BGRA:
-	return WEED_PALETTE_BGRA32;
-    case PIX_FMT_ARGB:
-	return WEED_PALETTE_ARGB32;
-    case PIX_FMT_YUV444P:
-	return WEED_PALETTE_YUV444P;
-    case PIX_FMT_YUV422P:
-	return WEED_PALETTE_YUV422P;
-    case PIX_FMT_YUV420P:
-	return WEED_PALETTE_YUV420P;
-    case PIX_FMT_YUYV422:
-	return WEED_PALETTE_YUYV;
-    case PIX_FMT_UYVY422:
-	return WEED_PALETTE_UYVY;
-    case PIX_FMT_UYYVYY411:
-	return WEED_PALETTE_YUV411;
-    case PIX_FMT_GRAY8:
-    case PIX_FMT_Y400A:
-	return WEED_PALETTE_A8;
-    case PIX_FMT_MONOWHITE:
-    case PIX_FMT_MONOBLACK:
-	return WEED_PALETTE_A1;
-    case PIX_FMT_YUVJ422P:
-	if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-	return WEED_PALETTE_YUV422P;
-    case PIX_FMT_YUVJ444P:
-	if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-	return WEED_PALETTE_YUV444P;
-    case PIX_FMT_YUVJ420P:
-	if (clamped) *clamped=WEED_YUV_CLAMPING_UNCLAMPED;
-	return WEED_PALETTE_YUV420P;
-
-    default:
-	return WEED_PALETTE_END;
-    }
-}
-
 
 
 /* can enable this later to handle pix_fmt (35) - YUVA4204P */
@@ -465,6 +432,7 @@ static int flv_get_extradata(lives_clip_data_t *cdata, int size) {
   if (priv->ctx->extradata==NULL) return AVERROR(ENOMEM);
   priv->ctx->extradata_size = size;
   dummy=read(priv->fd, priv->ctx->extradata, priv->ctx->extradata_size);
+  dummy=dummy; // keep compiler happy
   return 0;
 }
 
@@ -524,11 +492,11 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   unsigned char flags,avctype;
   int type,size,vcodec=0,ldts;
   boolean gotmeta=FALSE,in_array=FALSE;
-  boolean haskeyframes=FALSE,canseekend=FALSE,hasaudio;
+  boolean hasaudio;
   boolean got_astream=FALSE,got_vstream=FALSE;
   char *key=NULL;
   size_t offs=0;
-  double num_val,fps,lasttimestamp=-1.;
+  double num_val,fps;
 
   AVCodec *codec=NULL;
   AVCodecContext *ctx;
@@ -682,7 +650,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	if (!strcmp(key,"videoframerate")) cdata->fps=num_val;
 	if (!strcmp(key,"audiosamplerate")) cdata->arate=num_val;
 	if (!strcmp(key,"audiosamplesize")) cdata->asamps=num_val;
-	if (!strcmp(key,"lasttimestamp")) lasttimestamp=num_val;
+	//if (!strcmp(key,"lasttimestamp")) lasttimestamp=num_val;
 	if (!strcmp(key,"height")) cdata->height=num_val;
 	if (!strcmp(key,"width")) cdata->width=num_val;
 
@@ -698,10 +666,10 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
 	offs+=1;
 
-	if (!strcmp(key,"hasKeyframes")&&num_val==1.) haskeyframes=TRUE;
-	else if (!strcmp(key,"canSeekToEnd")&&num_val==1.) canseekend=TRUE;
-	else if (!strcmp(key,"hasAudio")&&num_val==0.) hasaudio=FALSE;
-	if (!strcmp(key,"stereo")&&num_val==1.) cdata->achans=2;
+	//if (!strcmp(key,"hasKeyframes")&&num_val==1.) haskeyframes=TRUE;
+	//else if (!strcmp(key,"canSeekToEnd")&&num_val==1.) canseekend=TRUE;
+	if (!strcmp(key,"hasAudio")&&num_val==0.) hasaudio=FALSE;
+	else if (!strcmp(key,"stereo")&&num_val==1.) cdata->achans=2;
 
 	if (key!=NULL) free(key);
 	key=NULL;
@@ -755,6 +723,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->ctx=ctx = avcodec_alloc_context();
 
+  sprintf(cdata->audio_name,"none");
+
   // now we get the stream data
   while (!got_astream || !got_vstream) {
     do {
@@ -1012,7 +982,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     int len;
 
     // this does not work for h264 and I dont know why not !!!!!!!!!!!!!!!!!!!!
-#if LIBAVCODEC_VERSION_MAJOR >= 53
+#if LIBAVCODEC_VERSION_MAJOR >= 52
     len=avcodec_decode_video2(ctx, priv->picture, &got_picture, &priv->avpkt );
 #else 
     len=avcodec_decode_video(ctx, priv->picture, &got_picture, priv->avpkt.data, priv->avpkt.size );
@@ -1089,7 +1059,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   cdata->palettes=(int *)malloc(2*sizeof(int));
 
-  cdata->palettes[0]=pix_fmt_to_palette(ctx->pix_fmt,&cdata->YUV_clamping);
+  cdata->palettes[0]=avi_pix_fmt_to_weed_palette(ctx->pix_fmt,
+						 &cdata->YUV_clamping);
   cdata->palettes[1]=WEED_PALETTE_END;
 
   if (cdata->palettes[0]==WEED_PALETTE_END) {
@@ -1106,6 +1077,11 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   if (cdata->width==0) cdata->width=ctx->width-cdata->offs_x*2;
   if (cdata->height==0) cdata->height=ctx->height-cdata->offs_y*2;
   
+  if (cdata->width*cdata->height==0) {
+    fprintf(stderr, "flv_decoder: invalid width and height (%d X %d)\n",cdata->width,cdata->height);
+    detach_stream(cdata);
+    return FALSE;
+  }
 
 #ifdef DEBUG
   fprintf(stderr,"using palette %d, size %d x %d\n",
@@ -1137,9 +1113,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     cdata->interlace=LIVES_INTERLACE_BOTTOM_FIRST;
   }
 
-   priv->last_frame=-1;
-
-  if (cdata->width*cdata->height==0) return FALSE;
+  priv->last_frame=-1;
 
   ldts=get_last_video_dts(cdata);
 
@@ -1460,8 +1434,10 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 	priv->avpkt.size-=len;
 	priv->avpkt.data+=len;
 
-	if (!got_picture&&priv->avpkt.size<=0) return FALSE;
-
+	if (!got_picture&&priv->avpkt.size<=0) {
+	  free(pack.data);
+	  return FALSE;
+	}
       }
 
       free(pack.data);
