@@ -56,6 +56,16 @@ int tvpic_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
   width*=offs;
 
+  // new threading arch
+  if (weed_plant_has_leaf(out_channel,"offset")) {
+    int offset=weed_get_int_value(out_channel,"offset",&error);
+    int dheight=weed_get_int_value(out_channel,"height",&error);
+
+    src+=offset*irowstride;
+    dest+=offset*orowstride;
+    end=src+dheight*irowstride;
+  }
+
   for (;src<end;src+=irowstride) {
     col=colrd=!colrd;
     if (!col) pc=0; // red
@@ -98,7 +108,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
     weed_plant_t *in_chantmpls[]={weed_channel_template_init("in channel 0",0,palette_list),NULL};
     weed_plant_t *out_chantmpls[]={weed_channel_template_init("out channel 0",WEED_CHANNEL_CAN_DO_INPLACE,palette_list),NULL};
-    weed_plant_t *filter_class=weed_filter_class_init("tvpic","salsaman",1,0,NULL,&tvpic_process,NULL,in_chantmpls,out_chantmpls,NULL,NULL);
+    weed_plant_t *filter_class=weed_filter_class_init("tvpic","salsaman",1,WEED_FILTER_HINT_MAY_THREAD,NULL,&tvpic_process,NULL,in_chantmpls,out_chantmpls,NULL,NULL);
 
     weed_plugin_info_add_filter_class (plugin_info,filter_class);
 
