@@ -227,11 +227,6 @@ void
 on_button3_clicked                     (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_ok_button3_clicked                  (GtkButton       *button,
-                                        gpointer         user_data);
-
-
 void
 on_full_screen_pressed (GtkButton *button,
 			gpointer user_data);
@@ -467,12 +462,6 @@ gboolean
 frame_context           (GtkWidget       *widget,
 			  GdkEventButton  *event,
 			  gpointer         which);
-
-void
-ok_save_frame                  (GtkButton       *button,
-				gpointer         frame);
-
-
 void
 on_fs_preview_clicked                  (GtkButton       *button,
                                         gpointer         user_data);
