@@ -18,11 +18,11 @@
 #include "resample.h"
 
 
-
-LIVES_INLINE gint count_virtual_frames(int *findex, int size) {
+/** count virtual frames between start and end (inclusive) */
+LIVES_INLINE gint count_virtual_frames(int *findex, int start, int end) {
   register int i;
   gint count=0;
-  for (i=0;i<size;i++) if (findex[i]!=-1) count++;
+  for (i=start-1;i<end;i++) if (findex[i]!=-1) count++;
   return count;
 }
 
@@ -368,3 +368,11 @@ int *frame_index_copy(int *findex, gint nframes) {
 
   return findexc;
 }
+
+
+gboolean is_virtual_frame(int sfileno, int frame) {
+  file *sfile=mainw->files[sfileno];
+  if (sfile->frame_index==NULL) return FALSE;
+  if (sfile->frame_index[frame-1]!=-1) return TRUE;
+  return FALSE;
+}
