@@ -28,8 +28,6 @@ typedef enum {
 } lives_filter_error_t;
 
 
-#define MAX_FX_THREADS 65536
-
 
 weed_plant_t *get_weed_filter(int filter_idx);
 gchar *weed_filter_get_name(int filter_idx);
@@ -162,7 +160,7 @@ gint rte_get_numfilters(void);
 void free_key_defaults(gint key, gint mode);
 void apply_key_defaults(weed_plant_t *inst, gint key, gint mode);
 void write_key_defaults(int fd, gint key, gint mode);
-void read_key_defaults(int fd, int nparams, int key, int mode, int version);
+gboolean read_key_defaults(int fd, int nparams, int key, int mode, int version);
 void set_key_defaults(weed_plant_t *inst, gint key, gint mode);
 gboolean has_key_defaults(void);
 
