@@ -97,7 +97,7 @@ gboolean lives_jack_init (void) {
   jack_activate(jack_transport_client);
   jack_set_sync_timeout(jack_transport_client,5000000); // seems to not work
   jack_set_sync_callback (jack_transport_client, lives_start_ready_callback, NULL);
-  gtk_timeout_add(KEY_RPT_INTERVAL,&lives_jack_poll,NULL);
+  mainw->jack_trans_poll=TRUE;
 #else
   jack_client_close (jack_transport_client);
   jack_transport_client=NULL;
@@ -120,9 +120,7 @@ gdouble jack_transport_get_time(void) {
 #ifdef ENABLE_JACK_TRANSPORT
   jack_nframes_t srate; 
   jack_position_t pos;
-  jack_transport_state_t jacktstate;
 
-  jacktstate=jack_transport_query (jack_transport_client, &pos);
   srate=jack_get_sample_rate(jack_transport_client);
   return (gdouble)pos.frame/(gdouble)srate;
 #endif
@@ -163,7 +161,7 @@ static void jack_transport_check_state (void) {
 }
 #endif
 
-gboolean lives_jack_poll(gpointer data) {
+gboolean lives_jack_poll(void) {
   // data is always NULL
   // must return TRUE
 #ifdef ENABLE_JACK_TRANSPORT
@@ -1298,7 +1296,7 @@ int jack_audio_init(void) {
     jackd->seek_pos=jackd->seek_end=0;
     jackd->msgq=NULL;
     jackd->num_calls=0;
-    //jackd->astream_file=NULL;
+    jackd->astream_fd=-1;
     jackd->jackd_died=FALSE;
     gettimeofday(&jackd->last_reconnect_attempt, 0);
     jackd->num_output_channels=2;
@@ -1331,7 +1329,7 @@ int jack_audio_read_init(void) {
     jackd->seek_pos=jackd->seek_end=0;
     jackd->msgq=NULL;
     jackd->num_calls=0;
-    //jackd->astream_file=NULL;
+    jackd->astream_fd=-1;
     jackd->jackd_died=FALSE;
     gettimeofday(&jackd->last_reconnect_attempt, 0);
     jackd->num_input_channels=2;
