@@ -256,9 +256,12 @@ void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
   weed_set_int_value(layer,"current_palette",WEED_PALETTE_YUV420P);
   weed_set_int_value(layer,"YUV_subspace",WEED_YUV_SUBSPACE_YCBCR);
 
-  create_empty_pixel_data(layer);
+  if (!yuv4mpeg->ready) {
+    create_empty_pixel_data(layer,FALSE);
+    return;
+  }
 
-  if (!yuv4mpeg->ready) return;
+  create_empty_pixel_data(layer,FALSE);
 
   yuv4mpeg->pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
 
@@ -339,7 +342,6 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
   // start "playing" but open frames in yuv4mpeg format on stdin
 
   gint old_file=mainw->current_file,new_file=mainw->first_free_file;
-  lives_yuv4m_t *yuv4mpeg;
   gchar *tmp;
   gchar *filename;
   gchar *fname;
@@ -381,8 +383,6 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
   g_free(tmp);
   g_free(filename);
 
-  yuv4mpeg=cfile->ext_src;
-
   d_print(_("Audio: "));
 
   if (cfile->achans==0) {
