@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@xs4all.nl) 2003 - 2010
+// (c) G. Finch (salsaman@xs4all.nl) 2003 - 2011
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     agint64 with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 */
 
 
@@ -152,7 +152,9 @@ POSSIBILITY OF SUCH DAMAGES.
 #  define WARN_UNUSED
 #endif
 
-
+#ifdef PRODUCE_LOG
+#define LIVES_LOG "lives.log"
+#endif
 
 /// this struct is used only when physically resampling frames on the disk
 /// we create an array of these and write them to the disk
@@ -645,7 +647,8 @@ void make_preview_box (void);
 void add_to_playframe (void);
 GtkWidget* create_cdtrack_dialog (gint type, gpointer user_data);
 GtkTextView *create_output_textview(void);
-gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, GtkFileChooserAction act, GtkWidget *extra);
+gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, GtkFileChooserAction act, const char *title, GtkWidget *extra);
+void add_suffix_check(GtkBox *box, const gchar *ext);
 
 
 // dialogs.c
@@ -657,7 +660,8 @@ gboolean do_yesno_dialog(const gchar *text);
 void do_error_dialog(const gchar *text);
 void do_error_dialog_with_check(const gchar *text, gint warn_mask_number);
 void do_blocking_error_dialog(const gchar *text);
-void do_error_dialog_with_check_transient(const gchar *text, gboolean is_blocking,gint warn_mask_number, GtkWindow *transient);
+void do_error_dialog_with_check_transient(const gchar *text, gboolean is_blocking,gint warn_mask_number, 
+					  GtkWindow *transient);
 void add_warn_check (GtkBox *box, gint warn_mask_number);
 void do_memory_error_dialog (void);
 void too_many_files(void);
@@ -672,8 +676,10 @@ gboolean do_comments_dialog (file *sfile, gchar *filename);
 void do_auto_dialog(const gchar *text, gint type);
 void do_encoder_acodec_error (void);
 void do_encoder_sox_error(void);
-gboolean rdet_suggest_values (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, gint arate, gint asigned, gboolean anr, gboolean ignore_fps);
-gboolean do_encoder_restrict_dialog (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, gint arate, gint asigned, gboolean anr);
+gboolean rdet_suggest_values (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, gint arate, 
+			      gint asigned, gboolean swap_endian, gboolean anr, gboolean ignore_fps);
+gboolean do_encoder_restrict_dialog (gint width, gint height, gdouble fps, gint fps_num, gint fps_denom, 
+				     gint arate, gint asigned, gboolean swap_endian, gboolean anr, gboolean save_all);
 void do_keys_window (void);
 void do_mt_keys_window (void);
 void do_messages_window (void);
@@ -725,6 +731,8 @@ void do_set_locked_warning (const gchar *setname);
 void do_no_in_vdevs_error(void);
 void do_locked_in_vdevs_error(void);
 void do_do_not_close_d (void);
+void do_set_noclips_error(const char *setname);
+
 
 gboolean process_one (gboolean visible);
 void do_threaded_dialog(gchar *translated_text, gboolean has_cancel);
@@ -758,9 +766,10 @@ gboolean get_new_handle(gint index, const gchar *name);
 gboolean get_temp_handle(gint index, gboolean create);
 void get_handle_from_info_file(gint index);
 void create_cfile(void);
-void save_file (gboolean existing, gchar *n_file_name);
+void save_file (int clip, int start, int end, const char *filename);
 void play_file (void);
-gboolean save_frame(gint clip, gint frame, const gchar *file_name, gint width, gint height);
+void save_frame (GtkMenuItem *menuitem, gpointer user_data);
+gboolean save_frame_inner(gint clip, gint frame, const gchar *file_name, gint width, gint height, gboolean auto_overwrite);
 void wait_for_stop (const gchar *stop_command);
 void save_clip_values(gint which_file);
 void add_to_recovery_file (const gchar *handle);
@@ -770,7 +779,7 @@ void recover_layout_map(gint numclips);
 const gchar *get_deinterlace_string(void);
 
 // saveplay.c backup
-void backup_file(const gchar *filename);
+void backup_file(int clip, int start, int end, const gchar *filename);
 gint save_event_frames(void);
 void write_headers (file *file);
 
@@ -801,8 +810,12 @@ void load_end_image(gint frame);
 void load_preview_image(gboolean update_always);
 
 gboolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc);
-gboolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, int width, int height, int target_palette);
-GdkPixbuf *pull_gdk_pixbuf_at_size(gint clip, gint frame, const gchar *image_ext, weed_timecode_t tc, gint width, gint height, GdkInterpType interp);
+gboolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, 
+			     int width, int height, int target_palette);
+GdkPixbuf *pull_gdk_pixbuf_at_size(gint clip, gint frame, const gchar *image_ext, weed_timecode_t tc, 
+				   gint width, gint height, GdkInterpType interp);
+GError * lives_pixbuf_save(GdkPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
+			   int quality, GError **gerrorptr);
 
 void load_frame_image(gint frame);
 void sensitize(void);
@@ -813,7 +826,6 @@ void get_next_free_file(void);
 void switch_to_file(gint old_file, gint new_file);
 void do_quick_switch (gint new_file);
 void resize (gdouble scale);
-GdkPixbuf *lives_scale_simple (GdkPixbuf *, gint width, gint height);
 gboolean read_file_details(const gchar *file_name, gboolean only_check_for_audio);
 void do_start_messages(void);
 void set_palette_colours (void);
@@ -862,11 +874,14 @@ void get_pref_default(const gchar *key, gchar *val, gint maxlen);
 gboolean get_boolean_pref(const gchar *key);
 gdouble get_double_pref(const gchar *key);
 gint get_int_pref(const gchar *key);
+GList *get_list_pref(const gchar *key);
 void get_location(const gchar *exe, gchar *val, gint maxlen);
 void set_pref (const gchar *key, const gchar *value);
+void delete_pref (const gchar *key);
 void set_boolean_pref(const gchar *key, gboolean value);
 void set_double_pref(const gchar *key, gdouble value);
 void set_int_pref(const gchar *key, gboolean value);
+void set_list_pref(const char *key, GList *values);
 gboolean apply_prefs(gboolean skip_warnings);
 void save_future_prefs(void);
 void set_menu_text(GtkWidget *menu, const gchar *text, gboolean use_mnemonic);
@@ -884,10 +899,10 @@ void set_alwaysontop(GtkWidget *window, gboolean ontop); ///< TODO - use for pla
 void colour_equal(GdkColor *c1, const GdkColor *c2);
 void switch_to_int_player(void);
 void switch_to_mplayer(void);
-void switch_aud_to_sox(void);
+void switch_aud_to_sox(gboolean set_pref);
 gboolean switch_aud_to_jack(void);
 gboolean switch_aud_to_pulse(void);
-void switch_aud_to_mplayer(void);
+void switch_aud_to_mplayer(gboolean set_pref);
 void prepare_to_play_foreign(void);
 gboolean after_foreign_play(void);
 gboolean check_file(const gchar *file_name, gboolean check_exists);  ///< check if file exists
@@ -914,7 +929,8 @@ void calc_maxspect(gint rwidth, gint rheight, gint *cwidth, gint *cheight);
 gchar *remove_trailing_zeroes(gdouble val);
 void toggle_button_toggle (GtkToggleButton *tbutton);
 void remove_layout_files(GList *lmap);
-gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer user_data, gint clipno, gint frameno, gdouble atime, gboolean affects_current);
+gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer user_data, 
+			gint clipno, gint frameno, gdouble atime, gboolean affects_current);
 void clear_lmap_errors(void);
 gboolean prompt_remove_layout_files(void);
 gboolean is_legal_set_name(const gchar *set_name, gboolean allow_dupes);
@@ -928,7 +944,8 @@ gboolean int_array_contains_value(int *array, int num_elems, int value);
 gboolean check_for_lock_file(const gchar *set_name, gint type);
 void g_list_free_strings(GList *list);
 void gtk_tooltips_copy(GtkWidget *dest, GtkWidget *source);
-void adjustment_configure(GtkAdjustment *adjustment, gdouble value, gdouble lower, gdouble upper, gdouble step_increment, gdouble page_increment, gdouble page_size);
+void adjustment_configure(GtkAdjustment *adjustment, gdouble value, gdouble lower, gdouble upper, 
+			  gdouble step_increment, gdouble page_increment, gdouble page_size);
 gboolean create_event_space(gint length_in_eventsb);
 void add_to_recent(const gchar *filename, gdouble start, gint frames, const gchar *file_open_params);
 gint verhash (gchar *version);
@@ -949,6 +966,9 @@ gint calc_new_playback_position(gint fileno, gint64 otc, gint64 *ntc);
 void minimise_aspect_delta (gdouble allowed_aspect,gint hblock,gint vblock,gint hsize,gint vsize,gint *width,gint *height);
 LIVES_INLINE gint get_interp_value(gshort quality);
 LIVES_INLINE GList *g_list_move_to_first(GList *list, GList *item) WARN_UNUSED;
+GList *g_list_delete_string(GList *, char *string) WARN_UNUSED;
+GList *g_list_copy_strings(GList *list);
+gboolean string_lists_differ(GList *, GList *);
 
 
 GList *get_set_list(const gchar *dir);
@@ -976,7 +996,7 @@ void text_view_set_text(GtkTextView *textview, const gchar *text);
 
 // plugins.c
 GList *get_external_window_hints(lives_rfx_t *rfx);
-gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio);
+gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio, gboolean save_all);
 
 //callbacks.c
 void lives_exit (void);
@@ -1041,4 +1061,8 @@ char *dummychar;
 #define LIVES_TV_CHANNEL1 "http://www.serverwillprovide.com/sorteal/livestvclips/livestv.ogm"
 
 
+// round up to next multiple of b
+#define CEIL(a,b) ((int)(((double)a+(double)b-.000000001)/((double)b))*b)
+
+
 #endif // #ifndef HAS_MAIN_H
