@@ -1,6 +1,6 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2010
+// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2011
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -55,6 +55,8 @@
 #define EFFECT_NONE 0
 #define GU641 ((guint64)1)
 
+#define MAX_FX_THREADS 65536
+
 
 /// max ext_cntl + 1
 #define MAX_EXT_CNTL 2
@@ -319,7 +321,6 @@ typedef struct {
   /////////////////////////////////////////////////
 
   // end of static-ish info
-  gboolean save_all;
   gchar first_info_file[256];
   gboolean leave_files;
   gboolean was_set;
@@ -350,6 +351,7 @@ typedef struct {
   gint64 deltaticks; ///< deltaticks for scratching
   gint64 firstticks; ///< ticks when audio started playing (for non-realtime audio plugins)
   gint64 stream_ticks;  ///< ticks since first frame sent to playback plugin
+  gint64 last_display_ticks; /// currticks when last display was shown (used for fixed fps)
 
   gboolean size_warn; ///< warn the user that incorrectly sized frames were found
 
@@ -442,6 +444,8 @@ typedef struct {
   gulong hnd_id;
   gulong loop_cont_func;
   gulong mute_audio_func;
+  gulong fullscreen_cb_func;
+  gulong sepwin_cb_func;
 
   // for jack transport
   gboolean jack_can_stop;
@@ -543,6 +547,7 @@ typedef struct {
   GtkWidget *sticky;
   GtkWidget *showfct;
   GtkWidget *showsubs;
+  GtkWidget *letter;
   GtkWidget *aload_subs;
   GtkWidget *load_subs;
   GtkWidget *erase_subs;
@@ -816,7 +821,7 @@ typedef struct {
   GMemVTable alt_vtable;
   void (*free_fn)(gpointer);
 
-  pthread_mutex_t gtk_mutex;  ///< gtk drawing mutex - used by the threaded dialog
+  pthread_mutex_t gtk_mutex;  ///< gtk drawing mutex - no longer used
   pthread_mutex_t interp_mutex;  ///< interpolation mutex - parameter interpolation must be single threaded
 
   pthread_mutex_t abuf_mutex;  ///< used to synch audio buffer request count - shared between audio and video threads
@@ -908,6 +913,10 @@ typedef struct {
   pthread_t sig_pid;
   gchar *sig_file;
 
+  gboolean has_custom_tools;
+  gboolean has_custom_gens;
+  gboolean has_custom_utilities;
+
   /// decoders
   gboolean decoders_loaded;
   GList *decoder_list;
@@ -926,6 +935,10 @@ typedef struct {
 
   gchar vpp_defs_file[PATH_MAX];
 
+  int log_fd;
+
+  gboolean jack_trans_poll;
+
 } mainwindow;
 
 GdkCursor *hidden_cursor;
