@@ -804,7 +804,7 @@ void rs_to_tc (GtkMenuItem *, gpointer mt);
 void re_to_tc (GtkMenuItem *, gpointer mt);
 gboolean mt_mark_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
 void multitrack_clear_marks (GtkMenuItem *, gpointer mt);
-void mt_show_current_frame(lives_mt *);  ///< preview th current frame (non-effects mode)
+void mt_show_current_frame(lives_mt *, gboolean return_layer);  ///< preview the current frame
 void mt_clear_timeline(lives_mt *mt);
 
 
@@ -913,6 +913,9 @@ void mt_clip_select (lives_mt *, gboolean scroll);
 void mt_delete_clips(lives_mt *, gint file);
 void mt_init_clips (lives_mt *, gint orig_file, gboolean add);
 
+// key shortcuts
+gboolean mt_prevclip (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
+gboolean mt_nextclip (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data);
 
 typedef enum {
   /* default to warn about */
