@@ -124,8 +124,8 @@ GList *filter_encoders_by_img_ext(GList *encoders, const gchar *img_ext);
 typedef struct {
   gchar name[51];
   guint32 audio_codec;
-  // must match with the "acodec" GList in interface.c
-  // and bitmaps in the encoder plugins
+  // match with bitmaps in the encoder plugins
+  // and also anames array in plugins.c (see below)
 
 #define AUDIO_CODEC_MP3 0
 #define AUDIO_CODEC_PCM 1
@@ -134,7 +134,8 @@ typedef struct {
 #define AUDIO_CODEC_AC3 4
 #define AUDIO_CODEC_AAC 5
 #define AUDIO_CODEC_AMR_NB 6
-#define AUDIO_CODEC_RAW 7
+#define AUDIO_CODEC_RAW 7       // reserved
+#define AUDIO_CODEC_WMA2 8
 
 #define AUDIO_CODEC_MAX 31
   //
@@ -159,6 +160,7 @@ typedef struct {
 _encoder;
 
 
+// defined in plugins.c for the whole app
 extern const char *anames[AUDIO_CODEC_MAX];
 
 
@@ -184,7 +186,7 @@ typedef struct {
   gint current_clip; ///< current clip number in container (starts at 0, MUST be <= nclips) [rw host]
 
   // video data
-  gint width;
+  gint width; // width and height of picture in frame
   gint height;
   gint64 nframes;
   lives_interlace_t interlace;
@@ -193,7 +195,7 @@ typedef struct {
   /// for primary pixel plane
   gint offs_x;
   gint offs_y;
-  gint frame_width;
+  gint frame_width; // frame width and height are the size of the outer frame
   gint frame_height;
 
   gfloat par; ///< pixel aspect ratio
