@@ -96,6 +96,7 @@ typedef struct {
 
 #define WARN_MASK_CLEAN_AFTER_CRASH (1<<24)
 
+#define WARN_MASK_NO_PULSE_CONNECT (1<<25)
 
   gchar effect_command[256];
   gchar video_open_command[256];
@@ -213,8 +214,6 @@ typedef struct {
 
   gboolean osc_start;
 
-  gboolean show_threaded_dialog;
-
   gboolean collate_images;
 
   gint virt_height; ///< n screens vert.
@@ -276,6 +275,10 @@ typedef struct {
 
   gboolean stream_audio_out;
   gboolean unstable_fx;
+  gboolean letterbox; ///< playback with letterbox
+  gboolean enc_letterbox; ///< encode with letterbox
+
+  GList *disabled_decoders;
 } _prefs;
 
 enum {
@@ -380,6 +383,7 @@ typedef struct {
   GtkWidget *checkbutton_warn_layout_popup;
   GtkWidget *checkbutton_warn_discard_layout;
   GtkWidget *checkbutton_warn_after_dvgrab;
+  GtkWidget *checkbutton_warn_no_pulse;
   GtkWidget *checkbutton_show_stats;
   GtkWidget *check_xmms_pause;
   GtkWidget *checkbutton_warn_fsize;
@@ -435,6 +439,7 @@ typedef struct {
   GtkWidget *forcesmon;
   GList *pbq_list;
   gchar *audp_name;
+  gchar *orig_audp_name;
   gulong audp_entry_func;
   GtkWidget *checkbutton_omc_js;
   GtkWidget *checkbutton_omc_midi;
@@ -485,6 +490,9 @@ typedef struct {
 
   gint nfx_threads;
 
+  GList *disabled_decoders;
+  GList *disabled_decoders_new;
+
 } _future_prefs;
 
 _prefs *prefs;
@@ -516,4 +524,6 @@ void set_combo_box_active_string(GtkComboBox *, gchar *active_str);
 
 void prefsw_set_astream_settings(_vid_playback_plugin *);
 
+void apply_button_set_enabled(GtkWidget *widget, gpointer func_data);
+
 #endif
