@@ -1,6 +1,6 @@
 // utils.c
 // LiVES
-// (c) G. Finch 2003 - 2010 <salsaman@xs4all.nl>
+// (c) G. Finch 2003 - 2011 <salsaman@xs4all.nl>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -193,6 +193,21 @@ static gboolean check_for_audio_stop (gint fileno, gint first_frame, gint last_f
 }
 
 
+static void calc_aframeno(gint fileno) {
+#ifdef ENABLE_JACK
+  if (prefs->audio_player==AUD_PLAYER_JACK&&mainw->jackd!=NULL&&mainw->jackd->playing_file==fileno) {
+    // get seek_pos from jack
+    mainw->aframeno=lives_jack_get_pos(mainw->jackd)/cfile->fps+1.;
+  }
+#endif
+#ifdef HAVE_PULSE_AUDIO
+  if (prefs->audio_player==AUD_PLAYER_PULSE&&mainw->pulsed!=NULL&&mainw->pulsed->playing_file==fileno) {
+    // get seek_pos from pulse
+    mainw->aframeno=lives_pulse_get_pos(mainw->pulsed)/cfile->fps+1.;
+  }
+#endif
+}
+
 
 
 
@@ -240,28 +255,12 @@ gint calc_new_playback_position(gint fileno, gint64 otc, gint64 *ntc) {
 
   if (sfile==NULL) return 0;
 
-  // calculate audio "frame"
-  if (mainw->playing_file==fileno) {
-#ifdef ENABLE_JACK
-    if (prefs->audio_player==AUD_PLAYER_JACK&&mainw->jackd!=NULL&&mainw->jackd->playing_file==fileno) {
-      // get seek_pos from jack
-      mainw->aframeno=lives_jack_get_pos(mainw->jackd)/cfile->fps+1.;
-    }
-#endif
-#ifdef HAVE_PULSE_AUDIO
-    // request for another audio buffer - used only during mt playback
-    if (prefs->audio_player==AUD_PLAYER_PULSE&&mainw->pulsed!=NULL&&mainw->pulsed->playing_file==fileno) {
-      // get seek_pos from pulse
-      mainw->aframeno=lives_pulse_get_pos(mainw->pulsed)/cfile->fps+1.;
-    }
-#endif
-  }
-
 
   cframe=sfile->last_frameno;
 
   if (fps==0.) {
     *ntc=otc;
+    calc_aframeno(fileno);
     return cframe;
   }
 
@@ -273,6 +272,11 @@ gint calc_new_playback_position(gint fileno, gint64 otc, gint64 *ntc) {
 
   if (nframe==cframe||mainw->foreign) return nframe;
 
+  // calculate audio "frame"
+  if (mainw->playing_file==fileno) {
+    calc_aframeno(fileno);
+  }
+
   if (mainw->playing_file==fileno) {
     last_frame=(mainw->playing_sel&&!mainw->is_rendering)?sfile->end:mainw->play_end;
     first_frame=mainw->playing_sel?sfile->start:1;
@@ -435,6 +439,19 @@ void calc_maxspect(gint rwidth, gint rheight, gint *cwidth, gint *cheight) {
 
   if (*cwidth<=0||*cheight<=0||rwidth<=0||rheight<=0) return;
 
+  if (*cwidth>rwidth) {
+    // image too wide shrink it
+    aspect=(gdouble)rwidth/(gdouble)(*cwidth);
+    *cwidth=rwidth;
+    *cheight=(gdouble)(*cheight)*aspect;
+  }
+  if (*cheight>rheight) {
+    // image too tall shrink it
+    aspect=(gdouble)rheight/(gdouble)(*cheight);
+    *cheight=rheight;
+    *cwidth=(gdouble)(*cwidth)*aspect;
+  }
+
   aspect=(gdouble)*cwidth/(gdouble)*cheight;
 
   if ((gdouble)rheight*aspect<=rwidth) {
@@ -590,8 +607,6 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     break;
   }
 
-  gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
-
   if (affects_current&&user_data!=NULL) {
     mainw->affected_layout_marks=g_list_append(mainw->affected_layout_marks,(gpointer)gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(mainw->layout_textbuffer),NULL,&end_iter,TRUE));
   }
@@ -603,8 +618,8 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       array=g_strsplit(lmap->data,"|",-1);
       text=g_strdup_printf("%s\n",array[0]);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_free(text);
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_strfreev(array);
       lmap=lmap->next;
     }
@@ -614,10 +629,9 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
 
-      gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
       mainw->affected_layout_marks=g_list_append(mainw->affected_layout_marks,(gpointer)gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(mainw->layout_textbuffer),NULL,&end_iter,TRUE));
 
     }
@@ -626,8 +640,8 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       array=g_strsplit(lmap->data,"|",-1);
       text=g_strdup_printf("%s\n",array[0]);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_free(text);
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       g_strfreev(array);
       lmap=lmap->next;
     }
@@ -638,10 +652,9 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
 
-      gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
       mainw->affected_layout_marks=g_list_append(mainw->affected_layout_marks,(gpointer)gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(mainw->layout_textbuffer),NULL,&end_iter,TRUE));
     }
     lmap=(GList *)user_data;
@@ -650,10 +663,10 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       orig_fps=strtod(array[3],NULL);
       resampled_frame=count_resampled_frames(frameno,orig_fps,mainw->files[clipno]->fps);
       if (resampled_frame<=atoi(array[2])) {
-	text=g_strdup(array[0]);
-	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
-	if (g_list_find(mainw->affected_layouts_map,array[0])==NULL) mainw->affected_layouts_map=g_list_append(mainw->affected_layouts_map,g_strdup(array[0]));
+	text=g_strdup_printf("%s\n",array[0]);
+	gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
 	g_free(text);
+	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       }
       g_strfreev(array);
       lmap=lmap->next;
@@ -665,10 +678,9 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
     if (affects_current) {
       text=g_strdup_printf("%s\n",mainw->cl_string);
       gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
       g_free(text);
+      mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,mainw->cl_string);
 
-      gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter);
       mainw->affected_layout_marks=g_list_append(mainw->affected_layout_marks,(gpointer)gtk_text_buffer_create_mark(GTK_TEXT_BUFFER(mainw->layout_textbuffer),NULL,&end_iter,TRUE));
     }
     lmap=(GList *)user_data;
@@ -676,10 +688,10 @@ gboolean add_lmap_error(lives_lmap_error_t lerror, const gchar *name, gpointer u
       array=g_strsplit(lmap->data,"|",-1);
       max_time=strtod(array[4],NULL);
       if (max_time>0.&&atime<=max_time) {
-	text=g_strdup(array[0]);
+	text=g_strdup_printf("%s\n",array[0]);
 	gtk_text_buffer_insert(GTK_TEXT_BUFFER(mainw->layout_textbuffer),&end_iter,text,-1);
-	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
 	g_free(text);
+	mainw->affected_layouts_map=g_list_append_unique(mainw->affected_layouts_map,array[0]);
       }
       g_strfreev(array);
       lmap=lmap->next;
@@ -729,8 +741,6 @@ gboolean check_for_lock_file(const gchar *set_name, gint type) {
   gchar *info_file=g_strdup_printf("%s/.locks.%d",prefs->tmpdir,getpid());
   gchar *com=g_strdup_printf("smogrify check_for_lock \"%s\" %s %d >%s",set_name,capable->myname,getpid(),info_file);
 
-  int lockpid;
-
   unlink(info_file);
   threaded_dialog_spin();
   dummyvar=system(com);
@@ -744,7 +754,6 @@ gboolean check_for_lock_file(const gchar *set_name, gint type) {
     if ((bytes=read(info_fd,mainw->msg,256))>0) {
       close(info_fd);
       memset(mainw->msg+bytes,0,1);
-      lockpid=atoi(mainw->msg);
 
       if (type==0) {
 	msg=g_strdup_printf(_("Set %s\ncannot be opened, as it is in use\nby another copy of LiVES.\n"),set_name);
@@ -1166,7 +1175,7 @@ get_play_times(void) {
   if (cfile->achans>0) {
     if (mainw->playing_file>-1) {
       offset_left=((mainw->playing_sel&&(prefs->audio_player==AUD_PLAYER_JACK||prefs->audio_player==AUD_PLAYER_PULSE))?cfile->start-1.:mainw->audio_start-1.)/cfile->fps/cfile->total_time*allocwidth;
-      if (mainw->audio_end) {
+      if (mainw->audio_end&&!mainw->loop) {
 	offset_right=(((prefs->audio_player==AUD_PLAYER_JACK||prefs->audio_player==AUD_PLAYER_PULSE))?cfile->end:mainw->audio_end)/cfile->fps/cfile->total_time*allocwidth;
       }
       else {
@@ -2331,14 +2340,13 @@ sget_file_size(const gchar *name) {
   struct stat filestat;
   int fd;
 
-  if ((fd=open(name,O_RDONLY))>-1) {
-    close (fd);
-  }
-  else {
+  if ((fd=open(name,O_RDONLY))==-1) {
     return (guint)0;
   }
 
-  stat(name,&filestat);
+  fstat(fd,&filestat);
+  close(fd);
+
   return (gulong)(filestat.st_size);
 }
 
@@ -2576,6 +2584,22 @@ verhash (gchar *version) {
 
 
 
+#ifdef PRODUCE_LOG
+void lives_log(const char *what) {
+  char *lives_log_file=g_strdup_printf("%s/%s",prefs->tmpdir,LIVES_LOG_FILE);
+  if (mainw->log_fd<0) mainw->log_fd=open(lives_log_file,O_WRONLY|O_CREAT,S_IRUSER|S_IWUSER);
+  if (mainw->log_fd!=-1) {
+    char *msg=g_strdup("%s|%d|",what,mainw->current_file);
+    write (mainw->log_fd,msg,strlen(msg));
+    g_free(msg);
+  }
+  g_free(lives_log_file);
+}
+#endif
+
+
+
+
 // TODO - move into undo.c
 void 
 set_undoable (const gchar *what, gboolean sensitive) {
@@ -2601,6 +2625,12 @@ set_undoable (const gchar *what, gboolean sensitive) {
   gtk_widget_hide(mainw->redo);
   gtk_widget_show(mainw->undo);
   gtk_widget_set_sensitive (mainw->undo,sensitive);
+
+#ifdef PRODUCE_LOG
+  lives_log(what);
+#endif
+
+
 }
 
 void 
@@ -2680,7 +2710,6 @@ void cache_file_contents(const gchar *filename) {
 
   if (!(hfile=fopen(filename,"r"))) return;
   while (fgets(buff,65536,hfile)!=NULL) {
-    threaded_dialog_spin();
     mainw->cached_list=g_list_append(mainw->cached_list,g_strdup(buff));
     threaded_dialog_spin();
   }
@@ -2868,13 +2897,12 @@ gboolean get_clip_value(int which, lives_clip_details_t what, void *retval, size
     }
     
     vfile=g_strdup_printf("%s/.smogval.%d.%d",prefs->tmpdir,getuid(),getpid());
-    threaded_dialog_spin();
+
     do {
       if (!(valfile=fopen(vfile,"r"))) {
 	if (!(mainw==NULL)) {
 	  threaded_dialog_spin();
 	  while (g_main_context_iteration(NULL,FALSE));
-	  threaded_dialog_spin();
 	}
 	g_usleep(prefs->sleep_time);
 	timeout--;
@@ -3276,10 +3304,8 @@ void
 get_border_size (GtkWidget *win, gint *bx, gint *by) {
   GdkRectangle rect;
   gint wx,wy;
-  threaded_dialog_spin();
   gdk_window_get_frame_extents (GDK_WINDOW (win->window),&rect);
   gdk_window_get_origin (GDK_WINDOW (win->window), &wx, &wy);
-  threaded_dialog_spin();
   bx[0]=wx-rect.x;
   by[0]=wy-rect.y;
 }
