@@ -127,7 +127,7 @@ gboolean weed_layer_set_from_lvdev (weed_plant_t *layer, file *sfile, gdouble ti
   weed_set_int_value(layer,"YUV_sampling",WEED_YUV_SAMPLING_DEFAULT); // TODO - use ldev->YUV_sampling
   weed_set_int_value(layer,"YUV_clamping",ldev->YUV_clamping);
 
-  create_empty_pixel_data(layer);
+  create_empty_pixel_data(layer,TRUE);
 
   if (ldev->buffer_type==UNICAP_BUFFER_TYPE_USER) {
 
@@ -474,7 +474,7 @@ void on_open_vdev_activate (GtkMenuItem *menuitem, gpointer user_data) {
   for (i = 0; SUCCESS (status) && (dev_count < MAX_DEVICES); i++) {
     status = unicap_enumerate_devices (NULL, &devices[i], i);
     if (!SUCCESS (status)) {
-      g_printerr("Failed to get list of devices\n");
+      if (i==0) g_printerr("Failed to get list of devices\n");
       break;
     }
   }
